<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>AddMeta</name>
    <message>
        <source>Insert a:</source>
        <translation>Vložit:</translation>
    </message>
    <message>
        <source>&amp;Marker</source>
        <translation>&amp;Značka</translation>
    </message>
    <message>
        <source>Voice &amp;Track</source>
        <translation>Stopa &amp;hlasu</translation>
    </message>
    <message>
        <source>Log C&amp;hain</source>
        <translation>Ř&amp;etězec zápisu</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Z&amp;rušit</translation>
    </message>
</context>
<context>
    <name>EditChain</name>
    <message>
        <source>Edit Log Chain</source>
        <translation>Upravit řetězec zápisu</translation>
    </message>
    <message>
        <source>Start at:</source>
        <translation type="obsolete">Začít na:</translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation type="obsolete">Činnost, když předchozí událost ještě běží</translation>
    </message>
    <message>
        <source>Start Immediately</source>
        <translation type="obsolete">Spustit ihned</translation>
    </message>
    <message>
        <source>Make Next</source>
        <translation type="obsolete">Jako další</translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation type="obsolete">Počkat až do</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="obsolete">Přehrát</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation type="obsolete">Přechod</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="obsolete">Zastavit</translation>
    </message>
    <message>
        <source>Transition Type:</source>
        <translation type="obsolete">Typ přechodu:</translation>
    </message>
    <message>
        <source>Log Name</source>
        <translation>Název zápisu</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Vybrat</translation>
    </message>
    <message>
        <source>Log Description</source>
        <translation>Popis zápisu</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">Z&amp;rušit</translation>
    </message>
    <message>
        <source>Transition If Previous Cart Ends Before</source>
        <translation type="obsolete">Přechod, když předchozí vozík skončí dříve</translation>
    </message>
</context>
<context>
    <name>EditLog</name>
    <message>
        <source>Edit Log</source>
        <translation>Upravit zápis</translation>
    </message>
    <message>
        <source>Log Name:</source>
        <translation>Název zápisu:</translation>
    </message>
    <message>
        <source>Tracks:</source>
        <translation>Stopy:</translation>
    </message>
    <message>
        <source>Origin:</source>
        <translation>Původ:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Popis:</translation>
    </message>
    <message>
        <source>Service:</source>
        <translation>Služba:</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ano</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Ne</translation>
    </message>
    <message>
        <source>Enable AutoRefresh:</source>
        <translation>Povolit automatické obnovení:</translation>
    </message>
    <message>
        <source>Start Date:</source>
        <translation>Počáteční datum:</translation>
    </message>
    <message>
        <source>End Date:</source>
        <translation>Koncové datum:</translation>
    </message>
    <message>
        <source>Start Date Enabled</source>
        <translation>Počáteční datum povoleno</translation>
    </message>
    <message>
        <source>End Date Enabled</source>
        <translation>Koncové datum povoleno</translation>
    </message>
    <message>
        <source>TIME</source>
        <translation type="obsolete">ČAS</translation>
    </message>
    <message>
        <source>TRANS</source>
        <translation type="obsolete">PŘECHOD</translation>
    </message>
    <message>
        <source>CART</source>
        <translation type="obsolete">VOZÍK</translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation type="obsolete">SKUPINA</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation type="obsolete">DÉLKA</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation type="obsolete">NÁZEV</translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation type="obsolete">UMĚLEC</translation>
    </message>
    <message>
        <source>CLIENT</source>
        <translation type="obsolete">ZÁKAZNÍK</translation>
    </message>
    <message>
        <source>AGENCY</source>
        <translation type="obsolete">AGENTURA</translation>
    </message>
    <message>
        <source>LABEL</source>
        <translation type="obsolete">ŠTÍTEK</translation>
    </message>
    <message>
        <source>SOURCE</source>
        <translation type="obsolete">ZDROJ</translation>
    </message>
    <message>
        <source>LINE ID</source>
        <translation type="obsolete">ID ŘÁDKU</translation>
    </message>
    <message>
        <source>COUNT</source>
        <translation type="obsolete">POČÍTADLO</translation>
    </message>
    <message>
        <source>Insert
Cart</source>
        <translation>Vložit
vozík</translation>
    </message>
    <message>
        <source>Insert
Meta</source>
        <translation>Vložit
popisná data</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Upravit</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Vyjmout</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Vložit</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Uložit</translation>
    </message>
    <message>
        <source>Save
&amp;As</source>
        <translation type="obsolete">Uložit
&amp;jako</translation>
    </message>
    <message>
        <source>&amp;Reports</source>
        <translation>Z&amp;právy</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Z&amp;rušit</translation>
    </message>
    <message>
        <source>Invalid Carts</source>
        <translation>Neplatné vozíky</translation>
    </message>
    <message>
        <source>This log contains one or more carts
that are invalid for the selected service!</source>
        <translation>Tento zápis obsahuje jeden nebo více vozíků,
jež jsou pro vybranou službu neplatné!</translation>
    </message>
    <message>
        <source>Voice Track</source>
        <translation>Stopa hlasu</translation>
    </message>
    <message>
        <source>The log contains carts that are disabled
for the selected service!

Do you still want to save?</source>
        <translation>Tento zápis obsahuje vozíky,
jež nejsou pro vybranou službu dostupné!

Přesto chcete uložit?</translation>
    </message>
    <message>
        <source>Add Log</source>
        <translation>Přidat zápis</translation>
    </message>
    <message>
        <source>Log Exists</source>
        <translation type="obsolete">Zápis existuje</translation>
    </message>
    <message>
        <source>Log Already Exists!</source>
        <translation type="obsolete">Zápis již existuje!</translation>
    </message>
    <message>
        <source>RDLogEdit</source>
        <translation>RDLogEdit</translation>
    </message>
    <message>
        <source>The log has been modified.
Do you want to save your changes?</source>
        <translation>Zápis byl změněn.
Chcete uložit změny?</translation>
    </message>
    <message>
        <source>The log contains carts that are disabled
for the selected service!</source>
        <translation>Tento zápis obsahuje vozíky,
jež jsou pro vybranou službu zakázány!</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation>PŘEHRÁT</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation>ZASTAVIT</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation>PŘECHOD</translation>
    </message>
    <message>
        <source>[cart not found]</source>
        <translation>[vozík nenalezen]</translation>
    </message>
    <message>
        <source>MARKER</source>
        <translation>ZNAČKA</translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation>STOPA</translation>
    </message>
    <message>
        <source>LOG CHAIN</source>
        <translation>ŘETĚZEC ZÁPISU</translation>
    </message>
    <message>
        <source>LINK</source>
        <translation>ODKAZ</translation>
    </message>
    <message>
        <source>[music import]</source>
        <translation>[zavedení hudby]</translation>
    </message>
    <message>
        <source>[traffic import]</source>
        <translation>[zavedení přenosu]</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ruční</translation>
    </message>
    <message>
        <source>Traffic</source>
        <translation>Přenos</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Hudba</translation>
    </message>
    <message>
        <source>RDLogManager</source>
        <translation>RDLogManager</translation>
    </message>
    <message>
        <source>Voice Tracker</source>
        <translation>Rozdělovač hlasu</translation>
    </message>
    <message>
        <source>--- end of log ---</source>
        <translation>--- konec zápisu ---</translation>
    </message>
    <message>
        <source>[INVALID CART]</source>
        <translation>[NEPLATNÝ VOZÍK]</translation>
    </message>
    <message>
        <source>Next Stop:</source>
        <translation>Další zastavení:</translation>
    </message>
    <message>
        <source>Log End:</source>
        <translation>Konec zápisu:</translation>
    </message>
    <message>
        <source>Run Length</source>
        <translation type="unfinished">Délka běhu</translation>
    </message>
    <message>
        <source>Selected:</source>
        <translation>Vybráno:</translation>
    </message>
    <message>
        <source>Delete on</source>
        <translation>Smazat na</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Vybrat</translation>
    </message>
    <message>
        <source>Unable to save log, audio deletion error!</source>
        <translation>Soubor se zápisem nelze uložit, chyba při mazání zvuku!</translation>
    </message>
    <message>
        <source>Link Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Len</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>As</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Render</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User</source>
        <translation type="obsolete">Uživatel</translation>
    </message>
    <message>
        <source>Log Locked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log already being edited by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trans</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart</source>
        <translation type="unfinished">Vozík</translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished">Název</translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="unfinished">Umělec</translation>
    </message>
    <message>
        <source>Client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Agency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Štítek</translation>
    </message>
    <message>
        <source>Source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ext Data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Count</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scheduled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Start Times As</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sch. Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Estimated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Est. Time</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditLogLine</name>
    <message>
        <source>Edit Log Entry</source>
        <translation>Upravit záznam zápisu</translation>
    </message>
    <message>
        <source>Start at:</source>
        <translation type="obsolete">Začít na:</translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation type="obsolete">Činnost, když předchozí událost ještě běží</translation>
    </message>
    <message>
        <source>Start Immediately</source>
        <translation type="obsolete">Spustit ihned</translation>
    </message>
    <message>
        <source>Make Next</source>
        <translation type="obsolete">Jako další</translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation type="obsolete">Počkat až do</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="obsolete">Přehrát</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation type="obsolete">Přechod</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="obsolete">Zastavit</translation>
    </message>
    <message>
        <source>Transition Type:</source>
        <translation type="obsolete">Typ přechodu:</translation>
    </message>
    <message>
        <source>Cart</source>
        <translation>Vozík</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Artist</source>
        <translation>Umělec</translation>
    </message>
    <message>
        <source>Select
Cart</source>
        <translation>Vybrat
vozík</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">Z&amp;rušit</translation>
    </message>
    <message>
        <source>Transition If Previous Cart Ends Before</source>
        <translation type="obsolete">Přechod, když předchozí vozík skončí dříve</translation>
    </message>
    <message>
        <source>Missing Cart</source>
        <translation>Chybí vozík</translation>
    </message>
    <message>
        <source>You must supply a cart number!</source>
        <translation>Musíte zadat číslo vozíku!</translation>
    </message>
    <message>
        <source>Disabled Cart</source>
        <translation>Zakázaný vozík</translation>
    </message>
    <message>
        <source>This cart belongs to a disabled
group for the specified service!</source>
        <translation>Tento vozík náleží do zakázané skupiny
vybrané služby!</translation>
    </message>
    <message>
        <source>No Fade on Segue Out</source>
        <translation>Žádné prolínání při přechodu ven</translation>
    </message>
    <message>
        <source>Duplicate Start Time</source>
        <translation type="obsolete">Zdvojený čas začátku</translation>
    </message>
    <message>
        <source>An event is already scheduled with this start time!</source>
        <translation type="obsolete">Již existuje událost s tímto začátečním časem!</translation>
    </message>
</context>
<context>
    <name>EditMarker</name>
    <message>
        <source>Edit Log Marker</source>
        <translation>Upravit značku zápisu</translation>
    </message>
    <message>
        <source>Start at:</source>
        <translation type="obsolete">Začít na:</translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation type="obsolete">Činnost, když předchozí událost ještě běží</translation>
    </message>
    <message>
        <source>Start Immediately</source>
        <translation type="obsolete">Spustit ihned</translation>
    </message>
    <message>
        <source>Make Next</source>
        <translation type="obsolete">Jako další</translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation type="obsolete">Počkat až do</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="obsolete">Přehrát</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation type="obsolete">Přechod</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="obsolete">Zastavit</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Poznámka</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Štítek</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">Z&amp;rušit</translation>
    </message>
    <message>
        <source>Transition If Previous Cart Ends Before</source>
        <translation type="obsolete">Přechod, když předchozí vozík skončí dříve</translation>
    </message>
    <message>
        <source>Transition Type:</source>
        <translation type="obsolete">Typ přechodu:</translation>
    </message>
</context>
<context>
    <name>EditTrack</name>
    <message>
        <source>Edit Voice Track Marker</source>
        <translation>Upravit značku zápisu stopy hlasu</translation>
    </message>
    <message>
        <source>Start at:</source>
        <translation type="obsolete">Začít na:</translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation type="obsolete">Činnost, když předchozí událost ještě běží</translation>
    </message>
    <message>
        <source>Start Immediately</source>
        <translation type="obsolete">Spustit ihned</translation>
    </message>
    <message>
        <source>Make Next</source>
        <translation type="obsolete">Jako další</translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation type="obsolete">Počkat až do</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="obsolete">Přehrát</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation type="obsolete">Přechod</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="obsolete">Zastavit</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Poznámka</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">Z&amp;rušit</translation>
    </message>
    <message>
        <source>Transition If Previous Cart Ends Before</source>
        <translation type="obsolete">Přechod, když předchozí vozík skončí dříve</translation>
    </message>
    <message>
        <source>Transition Type:</source>
        <translation type="obsolete">Typ přechodu:</translation>
    </message>
</context>
<context>
    <name>ListLogs</name>
    <message>
        <source>Select a Log</source>
        <translation type="obsolete">Vybrat zápis</translation>
    </message>
    <message>
        <source>NAME</source>
        <translation type="obsolete">NÁZEV</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation type="obsolete">POPIS</translation>
    </message>
    <message>
        <source>SERVICE</source>
        <translation type="obsolete">SLUŽBA</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">Z&amp;rušit</translation>
    </message>
</context>
<context>
    <name>ListReports</name>
    <message>
        <source>RDLibrary Reports</source>
        <translation type="obsolete">Zprávy RDLibrary</translation>
    </message>
    <message>
        <source>Log Listing</source>
        <translation>Seznam zápisů</translation>
    </message>
    <message>
        <source>Log Exception Report</source>
        <translation>Zpráva o chybách v zápisu</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>&amp;Generate</source>
        <translation>Vy&amp;tvořit</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <source>[none]</source>
        <translation>[žádný]</translation>
    </message>
    <message>
        <source>Log Check</source>
        <translation>Přezkoušení zápisu</translation>
    </message>
    <message>
        <source>No exceptions found.</source>
        <translation>Nenalezena žádná chyba.</translation>
    </message>
    <message>
        <source>Effective Date:</source>
        <translation>Platné datum:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Vybrat</translation>
    </message>
    <message>
        <source>Reports</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDLogEdit - Host</source>
        <translation type="obsolete">RDLogEdit - Server</translation>
    </message>
    <message>
        <source>User: [Unknown]</source>
        <translation type="obsolete">Uživatel: [Neznámý]</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation type="obsolete">Nelze spojit</translation>
    </message>
    <message>
        <source>LOG NAME</source>
        <translation type="obsolete">NÁZEV ZÁPISU</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation type="obsolete">POPIS</translation>
    </message>
    <message>
        <source>SERVICE</source>
        <translation type="obsolete">SLUŽBA</translation>
    </message>
    <message>
        <source>MUSIC</source>
        <translation type="obsolete">HUDBA</translation>
    </message>
    <message>
        <source>TRAFFIC</source>
        <translation type="obsolete">PŘENOS</translation>
    </message>
    <message>
        <source>TRACKS</source>
        <translation type="obsolete">STOPY</translation>
    </message>
    <message>
        <source>VALID FROM</source>
        <translation type="obsolete">PLATNÉ OD</translation>
    </message>
    <message>
        <source>VALID TO</source>
        <translation type="obsolete">PLATNÉ DO</translation>
    </message>
    <message>
        <source>AUTO REFRESH</source>
        <translation type="obsolete">AUTOOBNOVA</translation>
    </message>
    <message>
        <source>ORIGIN</source>
        <translation type="obsolete">PŮVOD</translation>
    </message>
    <message>
        <source>LAST LINKED</source>
        <translation type="obsolete">NAPOSLEDY SPOJENO</translation>
    </message>
    <message>
        <source>LAST MODIFIED</source>
        <translation type="obsolete">NAPOSLEDY ZMĚNĚNO</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Přidat</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Upravit</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>S&amp;mazat</translation>
    </message>
    <message>
        <source>Voice
&amp;Tracker</source>
        <translation>&amp;Rozdělovač
hlasu</translation>
    </message>
    <message>
        <source>Log
Report</source>
        <translation>ZPRÁVA
o zápisu</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Uživatel</translation>
    </message>
    <message>
        <source>Add Log</source>
        <translation>Přidat zápis</translation>
    </message>
    <message>
        <source>Log Exists</source>
        <translation type="obsolete">Zápis existuje</translation>
    </message>
    <message>
        <source>Log Already Exists!</source>
        <translation type="obsolete">Zápis již existuje!</translation>
    </message>
    <message>
        <source>Delete Log</source>
        <translation>Smazat zápis</translation>
    </message>
    <message>
        <source>This will also delete the</source>
        <translation>Toto smaže i</translation>
    </message>
    <message>
        <source>voice tracks associated with this log.
Continue?</source>
        <translation type="obsolete">stopy hlasů spojených s tímto zápisem.
Pokračovat?</translation>
    </message>
    <message>
        <source>Tracks Exist</source>
        <translation>Stopa existuje</translation>
    </message>
    <message>
        <source>Always</source>
        <translation>Vždy</translation>
    </message>
    <message>
        <source>TFN</source>
        <translation>TFN</translation>
    </message>
    <message>
        <source>RDLogEdit</source>
        <translation type="obsolete">RDLogedit</translation>
    </message>
    <message>
        <source>Unable to delete log, audio deletion error!</source>
        <translation type="obsolete">Soubor se zápisem nelze smazat, chyba při mazání zvuku!</translation>
    </message>
    <message>
        <source>RDLogEdit -- Database Skew</source>
        <translation type="obsolete">RDLogEdit - Nesouměrnost v databázi</translation>
    </message>
    <message>
        <source>This version of RDLogEdit is incompatible with the version installed on the server.
See your system administrator for an update!</source>
        <translation type="obsolete">Tato verze RDLogEdit je neslučitelná s verzí nainstalovanou na serveru.
Vyhledejte svého správce systému kvůli aktualizaci!</translation>
    </message>
    <message>
        <source>Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete the</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>log?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>voice tracks associated with this log.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete these</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>logs?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>voice tracks associated with these logs.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to delete log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>audio deletion error!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>is in use by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown command option</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log Name</source>
        <translation type="unfinished">Název zápisu</translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished">Hudba</translation>
    </message>
    <message>
        <source>Traffic</source>
        <translation type="unfinished">Přenos</translation>
    </message>
    <message>
        <source>Tracks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Valid From</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Valid To</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto Refresh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Origin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last Linked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last Modified</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenderDialog</name>
    <message>
        <source>Render Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rendering Log...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Render Progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart/Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Render To</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select</source>
        <translation type="unfinished">Vybrat</translation>
    </message>
    <message>
        <source>Audio Parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[now]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>As Specified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Virtual Start Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Events</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Only Selected Events</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Include</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop Rendering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Treat as PLAY</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>At STOP transition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Render</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">Z&amp;rušit</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rendering Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VoiceTracker</name>
    <message>
        <source>Voice Tracker</source>
        <translation type="unfinished">Rozdělovač hlasu</translation>
    </message>
    <message>
        <source>Edit Cue Markers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Undo Segue Changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Start Point Here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set End Point Here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set to Hook Markers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Record</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Previous
Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Next
Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tracks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TIME</source>
        <translation type="obsolete">ČAS</translation>
    </message>
    <message>
        <source>TRANS</source>
        <translation type="obsolete">PŘECHOD</translation>
    </message>
    <message>
        <source>CART</source>
        <translation type="obsolete">VOZÍK</translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation type="obsolete">SKUPINA</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation type="obsolete">DÉLKA</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation type="obsolete">NÁZEV</translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation type="obsolete">UMĚLEC</translation>
    </message>
    <message>
        <source>Do Over</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hit Post</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert
Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete
Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Zavřít</translation>
    </message>
    <message>
        <source>No VoiceTrack Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No voicetracking group has been defined for this service,
therefore only existing transitions will be editable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart Creation Failure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to create new cart for voice track!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLogEdit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio Deletion Error!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation type="unfinished">STOPA</translation>
    </message>
    <message>
        <source>Voice Track</source>
        <translation type="unfinished">Stopa hlasu</translation>
    </message>
    <message>
        <source>Track List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No more tracks!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[end of log]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[cart not found]</source>
        <translation type="unfinished">[vozík nenalezen]</translation>
    </message>
    <message>
        <source>MARKER</source>
        <translation type="unfinished">ZNAČKA</translation>
    </message>
    <message>
        <source>LOG CHAIN</source>
        <translation type="unfinished">ŘETĚZEC ZÁPISU</translation>
    </message>
    <message>
        <source>LINK</source>
        <translation type="unfinished">ODKAZ</translation>
    </message>
    <message>
        <source>[music import]</source>
        <translation type="unfinished">[zavedení hudby]</translation>
    </message>
    <message>
        <source>[traffic import]</source>
        <translation type="unfinished">[zavedení přenosu]</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation type="unfinished">PŘEHRÁT</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation type="unfinished">PŘECHOD</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation type="unfinished">ZASTAVIT</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Segue Changed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save segue changes?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLogEdit - Voice Tracker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This cart cannot contain any additional cuts!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LABEL</source>
        <translation type="obsolete">ŠTÍTEK</translation>
    </message>
    <message>
        <source>Log Locked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log already being edited by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Talk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trans</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart</source>
        <translation type="unfinished">Vozík</translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished">Název</translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="unfinished">Umělec</translation>
    </message>
    <message>
        <source>Album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Štítek</translation>
    </message>
</context>
</TS>
